@@ -13,7 +13,7 @@ def python(filename, inputs):
 def cpp(filename, inputs):
     output = {}
     problem = filename.split(".")[0]
-    check_output(["g++", filename, "-g", "-O2", "-o", f"{problem}"])
+    check_output(["g++", filename, "-g", "-O2", "-std=gnu++17", "-o", f"{problem}"])
     startTime = time.time()
     for input in inputs:
         output[input] = check_output([f"./{problem}"], input=input, universal_newlines=True)
@@ -27,7 +27,7 @@ def cpp(filename, inputs):
 def c(filename, inputs):
     output = {}
     problem = filename.split(".")[0]
-    check_output(["gcc", filename, "-g", "-O2", "-o", f"{problem}"])
+    check_output(["gcc", filename, "-g", "-O2", "-std=gnu11", "-o", f"{problem}"])
     startTime = time.time()
     for input in inputs:
         output[input] = check_output([f"./{problem}"], input=input, universal_newlines=True)
@@ -51,4 +51,18 @@ def java(filename, inputs):
         check_output(["rm", "-rf", f"{problem}.class"])
     except:
         pass
+    return output, endTime
+
+def cSharp(filename, inputs):
+    output = {}
+    problem = filename.split(".")[0]
+    check_output(["dmcs", "-optimize+", "-r:System.Numerics", filename])
+    startTime = time.time()
+    for input in inputs:
+        output[input] = check_output([f"./{problem}.exe"], input=input, universal_newlines=True)
+    endTime = time.time() - startTime
+    try:
+        check_output(["rm", "-rf", f"{problem}.exe"])
+    except:
+        pass
     return output, endTime
\ No newline at end of file
